# 中国石油大学（北京）考试安排查询脚本  

[![](https://img.shields.io/badge/author-RhythmLian-blue)](https://img.shields.io/badge/author-RhythmLian-blue)
[![](https://img.shields.io/badge/version-2.4.2-green)](https://img.shields.io/badge/version-2.4.2-green)
[![](https://img.shields.io/badge/License-MIT-yellow)](https://img.shields.io/badge/License-MIT-yellow)

## 安装：`pip install CUP_EXAM`
## 使用：`$ exam`

## 运行结果:  

### New version 2.6

- 支持新版教务处，修复考试安排更新问题

### Old version 2.5

- 支持匹配更多的考试安排文件类型, 并输出合适的信息

### Old version 2.4.2

- 简化安装。

### Old version 2.4.1

- 更新：上线自动版本更新功能。

  ![10.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/10.png?raw=true)

- 问题:

  Windows系统可能没有“unzip"命令，程序将帮你下载安装程序，位置在运行程序的目录下。你需要手动安装它，并设置环境变量。

  #### 设置环境变量
  
  ```shell
  系统环境变量->PATH->编辑->尾部添加：“C:\Program Files (x86)\GnuWin32\bin;”
  ```

### Old version 2.3

- Update: add install.sh and start.sh to easy start.

  ![9.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/9.png?raw=true)

### Old version 2.2
- Update: Simplify search expressions and remove the dependency on the fuzzywuzzy library.   
  ![8.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/8.png?raw=true) 

### Old version 2.1
- Update: The program automatically maintains test scheduling files.  
  ![7.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/7.png?raw=true)  

### Old version 2.0  
- new feature  
  ![5.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/5.png?raw=true)  
  ![6.png](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/6.png?raw=true)  



- simple example  
  ![simple example](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/4.png?raw=true)  

### Old version 1.0  
![1.jpg](https://github.com/Rhythmicc/CUP_EXAM/blob/master/img/1.jpg?raw=true)  

- By the way, if the **content.xls** is existed, the program will not ask for a url. 

- And if you want to update it, you can delete it and input new url. 